@@ -1,6 +1,7 @@
 #' Get causal types
 #'
-#' Return data frame with types produced from all combinations of possible data produced by a DAG.
+#' Return data frame with types produced from all combinations of possible
+#' data produced by a DAG.
 #'
 #' @inheritParams CausalQueries_internal_inherit_params
 #' @return A \code{data.frame} indicating causal types of a \code{model}
@@ -11,9 +12,10 @@
 
 get_causal_types <- function(model) {
 
-    if (!is.null(model$causal_types))
-        return(model$causal_types)
+    if (!is.null(model$causal_types)) {
+      return(model$causal_types)
+    }
 
-    update_causal_types(model)
+    return(update_causal_types(model))
 }
 
